@@ -2,11 +2,11 @@
    	@file definitions.h
 
    	All definitions used widely in the application.
-
+   	<p>
 */
-/* 
- *
- * This file is part of Application Installer
+
+/*
+ * This file is part of osso-application-installer
  *
  * Copyright (C) 2005 Nokia Corporation.
  *
@@ -28,18 +28,16 @@
  * 02110-1301 USA
  *
  */
-#define UI_MARGIN_HORIZONTAL  12
 
-#define FAKEROOT_BINARY       "fakeroot"
-#define DPKG_BINARY           "dpkg"
-#define DPKG_QUERY_BINARY     "dpkg-query"
-#define DPKG_METHOD_LIST      1
-#define DPKG_METHOD_INSTALL   2
-#define DPKG_METHOD_UNINSTALL 3
-#define DPKG_METHOD_FIELDS    4
-#define DPKG_METHOD_STATUS    5
 
-#define DEFAULT_FOLDER        "/"
+#define UI_MARGIN_HORIZONTAL     12
 
-#define PATH_ENV              "PATH"
-#define PATH_ADD              ":/sbin:/usr/sbin"
+#define DEFAULT_FOLDER            "/"
+
+#define PATH_ENV                 "PATH"
+#define PATH_ADD                 ":/sbin:/usr/sbin"
+
+#define AI_HELP_KEY_MAIN "Utilities_ControlPanelAppletApplicationInstaller_applicationinstaller"
+#define AI_HELP_KEY_ERROR "Utilities_ControlPanelAppletApplicationInstaller_errordetails"
+#define AI_HELP_KEY_DEPENDS "Utilities_ControlPanelAppletApplicationInstaller_dependencyconflict"
+#define AI_HELP_KEY_INSTALL "Utilities_ControlPanelAppletApplicationInstaller_installapplication"
