@@ -1,10 +1,12 @@
 /**
     @file main.h
 
+    Main header file for OSSO Application Installer
+    <p>
 */
-/* 
- *
- * This file is part of Application Installer
+
+/*
+ * This file is part of osso-application-installer
  *
  * Copyright (C) 2005 Nokia Corporation.
  *
@@ -26,6 +28,8 @@
  * 02110-1301 USA
  *
  */
+
+
 #ifndef AI_MAIN_H_
 #define AI_MAIN_H_
 
@@ -36,7 +40,12 @@
 #include <locale.h>
 #include <osso-log.h>
 #include <signal.h>
-//#include <libgnomevfs/gnome-vfs.h>
+
+#define USE_GNOME_VFS 1
+
+#ifdef USE_GNOME_VFS
+# include <libgnomevfs/gnome-vfs.h>
+#endif
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
